// Copyright 2022 Clayton Craft <clayton@craftyguy.net>
// SPDX-License-Identifier: GPL-3.0-or-later

package config

import (
	"time"
)

type Type string

// Service types
const (
	TypeSimple  Type = "simple"
	TypeOneshot Type = "oneshot"
)

type ServiceConfig struct {
	Name                 string
	Description          string
	Type                 Type
	Restart              RestartCond
	RestartDur           time.Duration
	Cmd                  string
	CmdArgs              []string
	Env                  map[string]string
	Before               []string
	After                []string
	Autostart            bool
	Path                 string // path to the file that provided this config
	ExecStartPreCmd      string
	ExecStartPreCmdArgs  []string
	ExecStartPostCmd     string
	ExecStartPostCmdArgs []string
	ExecOnFailureCmd     string
	ExecOnFailureCmdArgs []string
	StartLimitDur        time.Duration
	StartLimitBurst      int
}

type RestartCond int

// Conditions for restarting the service
const (
	RestartAlways RestartCond = iota
	RestartFailure
	RestartSuccess
	RestartNever
)
